myfirstfun: My first R function

Description Usage Arguments Details Value Examples

View source: R/myfirstfun.R

Description

This is a first study on R functions

Usage

1

Arguments

x

A vector of quantitatve data

Details

The course MATH 4753 is an introduction to univariate stats with a heavy influence on tools and computer applications of statistics

Value

A vector of squared components

Examples

1
y <- 1:10; myfirstfun(y)

MATHSTATSOU/MATH4753STEWART4 documentation built on Feb. 18, 2021, 12:03 a.m.