Description Usage Arguments Details Value Examples
This is a first study on R functions
1 | myfirstfun(x)
|
x |
A vector of quantitatve data |
The course MATH 4753 is an introduction to univariate stats with a heavy influence on tools and computer applications of statistics
A vector of squared components
1 | y <- 1:10; myfirstfun(y)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.